@@ -50,6 +50,9 @@ INTEL_AUTHORITY = MetadataAuthority(
     metadata={},
 )
 
+DIRECTORY_ID = b"a" * 20
+DIRECTORY_SWHID = parse_swhid("swh:1:dir:" + DIRECTORY_ID.hex())
+
 
 def get_mock_deposit_cur(row_dicts):
     rows = [tuple(d[key] for key in DEPOSIT_COLS) for d in row_dicts]
@@ -91,6 +94,7 @@ def test_deposit_1():
 
     row = {
         "id": b"\x02#\x10\xdf\x16\xfd\x9eMO\x81\xfe6\xa1B\xe8-\xb9w\xc0\x1d",
+        "directory": DIRECTORY_ID,
         "date": datetime.datetime(2018, 1, 5, 0, 0, tzinfo=datetime.timezone.utc),
         "committer_date": datetime.datetime(
             2018, 1, 5, 0, 0, tzinfo=datetime.timezone.utc
@@ -139,7 +143,7 @@ def test_deposit_1():
         {
             "deposit.id": 467,
             "deposit.external_id": "check-deposit-2020-03-11T11:07:18.424476",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": extrinsic_metadata,
             "deposit_request.date": datetime.datetime(
@@ -152,7 +156,7 @@ def test_deposit_1():
         {
             "deposit.id": 467,
             "deposit.external_id": "check-deposit-2020-03-11T11:07:18.424476",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": None,
             "deposit_request.date": datetime.datetime(
@@ -182,10 +186,8 @@ def test_deposit_1():
         call.raw_extrinsic_metadata_add(
             [
                 RawExtrinsicMetadata(
-                    type=MetadataTargetType.REVISION,
-                    id=parse_swhid(
-                        "swh:1:rev:022310df16fd9e4d4f81fe36a142e82db977c01d"
-                    ),
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
                     discovery_date=datetime.datetime(
                         2020, 3, 11, 11, 7, 18, 688410, tzinfo=datetime.timezone.utc
                     ),
@@ -194,16 +196,17 @@ def test_deposit_1():
                     format="sword-v2-atom-codemeta-v2-in-json",
                     metadata=json.dumps(extrinsic_metadata).encode(),
                     origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:022310df16fd9e4d4f81fe36a142e82db977c01d"
+                    ),
                 ),
             ]
         ),
         call.raw_extrinsic_metadata_add(
             [
                 RawExtrinsicMetadata(
-                    type=MetadataTargetType.REVISION,
-                    id=parse_swhid(
-                        "swh:1:rev:022310df16fd9e4d4f81fe36a142e82db977c01d"
-                    ),
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
                     discovery_date=datetime.datetime(
                         2020, 3, 11, 11, 11, 36, 336283, tzinfo=datetime.timezone.utc
                     ),
@@ -212,6 +215,9 @@ def test_deposit_1():
                     format="original-artifacts-json",
                     metadata=json.dumps(original_artifacts).encode(),
                     origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:022310df16fd9e4d4f81fe36a142e82db977c01d"
+                    ),
                 ),
             ]
         ),
@@ -251,6 +257,7 @@ def test_deposit_2_without_xmlns():
 
     row = {
         "id": b"\x01\x16\xca\xb7\x19d\xd5\x9c\x85p\xb4\xc5r\x9b(\xbd\xd6<\x9bF",
+        "directory": DIRECTORY_ID,
         "date": datetime.datetime(
             2018, 1, 17, 12, 54, 0, 723882, tzinfo=datetime.timezone.utc
         ),
@@ -300,7 +307,7 @@ def test_deposit_2_without_xmlns():
         {
             "deposit.id": 82,
             "deposit.external_id": "hal-01243573",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": None,
             "deposit_request.date": datetime.datetime(
@@ -313,7 +320,7 @@ def test_deposit_2_without_xmlns():
         {
             "deposit.id": 82,
             "deposit.external_id": "hal-01243573",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": extrinsic_metadata,
             "deposit_request.date": datetime.datetime(
@@ -345,10 +352,8 @@ def test_deposit_2_without_xmlns():
         call.raw_extrinsic_metadata_add(
             [
                 RawExtrinsicMetadata(
-                    type=MetadataTargetType.REVISION,
-                    id=parse_swhid(
-                        "swh:1:rev:0116cab71964d59c8570b4c5729b28bdd63c9b46"
-                    ),
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
                     discovery_date=datetime.datetime(
                         2018, 1, 17, 12, 54, 0, 413748, tzinfo=datetime.timezone.utc
                     ),
@@ -357,16 +362,17 @@ def test_deposit_2_without_xmlns():
                     format="sword-v2-atom-codemeta-v2-in-json-with-expanded-namespaces",
                     metadata=json.dumps(extrinsic_metadata).encode(),
                     origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:0116cab71964d59c8570b4c5729b28bdd63c9b46"
+                    ),
                 ),
             ]
         ),
         call.raw_extrinsic_metadata_add(
             [
                 RawExtrinsicMetadata(
-                    type=MetadataTargetType.REVISION,
-                    id=parse_swhid(
-                        "swh:1:rev:0116cab71964d59c8570b4c5729b28bdd63c9b46"
-                    ),
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
                     discovery_date=datetime.datetime(
                         2020, 5, 15, 14, 27, 21, 462270, tzinfo=datetime.timezone.utc
                     ),
@@ -375,6 +381,9 @@ def test_deposit_2_without_xmlns():
                     format="original-artifacts-json",
                     metadata=json.dumps(original_artifacts).encode(),
                     origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:0116cab71964d59c8570b4c5729b28bdd63c9b46"
+                    ),
                 ),
             ]
         ),
@@ -414,6 +423,7 @@ def test_deposit_2_with_xmlns():
 
     row = {
         "id": b'\x01"\x96nP\x93\x17\xae\xcejA\xd0\xf0\x88\xdas<\xc0\x9d\x0f',
+        "directory": DIRECTORY_ID,
         "date": datetime.datetime(2018, 1, 5, 0, 0, tzinfo=datetime.timezone.utc),
         "committer_date": datetime.datetime(
             2018, 1, 5, 0, 0, tzinfo=datetime.timezone.utc
@@ -460,7 +470,7 @@ def test_deposit_2_with_xmlns():
         {
             "deposit.id": 687,
             "deposit.external_id": "check-deposit-2020-06-26T13:50:07.564420",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": extrinsic_metadata,
             "deposit_request.date": datetime.datetime(
@@ -473,7 +483,7 @@ def test_deposit_2_with_xmlns():
         {
             "deposit.id": 687,
             "deposit.external_id": "check-deposit-2020-06-26T13:50:07.564420",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": None,
             "deposit_request.date": datetime.datetime(
@@ -507,10 +517,8 @@ def test_deposit_2_with_xmlns():
         call.raw_extrinsic_metadata_add(
             [
                 RawExtrinsicMetadata(
-                    type=MetadataTargetType.REVISION,
-                    id=parse_swhid(
-                        "swh:1:rev:0122966e509317aece6a41d0f088da733cc09d0f"
-                    ),
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
                     discovery_date=datetime.datetime(
                         2020, 6, 26, 13, 50, 8, 216113, tzinfo=datetime.timezone.utc
                     ),
@@ -519,16 +527,17 @@ def test_deposit_2_with_xmlns():
                     format="sword-v2-atom-codemeta-v2-in-json",
                     metadata=json.dumps(extrinsic_metadata).encode(),
                     origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:0122966e509317aece6a41d0f088da733cc09d0f"
+                    ),
                 ),
             ]
         ),
         call.raw_extrinsic_metadata_add(
             [
                 RawExtrinsicMetadata(
-                    type=MetadataTargetType.REVISION,
-                    id=parse_swhid(
-                        "swh:1:rev:0122966e509317aece6a41d0f088da733cc09d0f"
-                    ),
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
                     discovery_date=datetime.datetime(
                         2020, 6, 26, 13, 50, 22, 640625, tzinfo=datetime.timezone.utc
                     ),
@@ -537,6 +546,173 @@ def test_deposit_2_with_xmlns():
                     format="original-artifacts-json",
                     metadata=json.dumps(original_artifacts).encode(),
                     origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:0122966e509317aece6a41d0f088da733cc09d0f"
+                    ),
+                ),
+            ]
+        ),
+    ]
+
+
+def test_deposit_2_with_json_in_json_and_no_xmlns():
+    """New formats introduced in https://forge.softwareheritage.org/D4105 ,
+    where the raw metadata is itself JSONed inside the metadata JSON tree
+    and https://forge.softwareheritage.org/D4065 where the @xmlns declarations
+    are stripped before being sent to the deposit DB"""
+    extrinsic_metadata = {
+        "id": "hal-02960679",
+        "author": {"name": "HAL", "email": "hal@ccsd.cnrs.fr"},
+        "client": "hal",
+        "codemeta:url": "https://hal.archives-ouvertes.fr/hal-02960679",
+        "codemeta:name": "Compressive Spectral Clustering Toolbox",
+        "codemeta:author": [
+            {"codemeta:name": "Nicolas Tremblay", "codemeta:affiliation": "PANAMA"},
+            {"codemeta:name": "Gilles Puy", "codemeta:affiliation": "PANAMA"},
+            {"codemeta:name": "R{\\'e}mi Gribonval", "codemeta:affiliation": "PANAMA"},
+            {"codemeta:name": "Pierre Vandergheynst"},
+        ],
+        # ...
+    }
+
+    original_artifacts = [
+        {
+            "url": "https://deposit.softwareheritage.org/1/private/1037/raw/",
+            "length": 4546913,
+            "filename": "archive.zip",
+            "checksums": {
+                "sha1": "01a0069c626a383de9a17ace40ecfd588e5c4f26",
+                "sha256": "c780a6de91286c70ceecc69fe0c6d201d3fe944aa89e193f3a89ae85dc25c3b1",
+            },
+        }
+    ]
+
+    row = {
+        "id": b"J\x9dc{\xa5\x07\xa2\xb93e%\x04(\xe6\xe3\xf0!\xf1\x94\xd0",
+        "directory": DIRECTORY_ID,
+        "date": datetime.datetime(2016, 1, 29, 0, 0, tzinfo=datetime.timezone.utc),
+        "committer_date": datetime.datetime(
+            2020, 10, 8, 0, 0, tzinfo=datetime.timezone.utc
+        ),
+        "type": "tar",
+        "message": b"hal: Deposit 1037 in collection hal",
+        "metadata": {
+            "extrinsic": {
+                "raw": {
+                    "origin": {
+                        "url": "https://hal.archives-ouvertes.fr/hal-02960679",
+                        "type": "deposit",
+                    },
+                    "origin_metadata": {
+                        "tool": {
+                            "name": "swh-deposit",
+                            "version": "0.2.0",
+                            "configuration": {"sword_version": "2"},
+                        },
+                        "metadata": json.dumps(extrinsic_metadata),
+                        "provider": {
+                            "metadata": {},
+                            "provider_url": "https://hal.archives-ouvertes.fr/",
+                            "provider_name": "hal",
+                            "provider_type": "deposit_client",
+                        },
+                    },
+                },
+                "when": "2020-10-09T13:38:25.888646+00:00",
+                "provider": "https://deposit.softwareheritage.org/1/private/1037/meta/",
+            },
+            "original_artifact": original_artifacts,
+        },
+    }
+
+    swhid = (
+        "swh:1:dir:8bfdf74037ae1c51335995891c6226e0f85e46e2"
+        ";origin=https://hal.archives-ouvertes.fr/hal-02960679"
+        ";visit=swh:1:snp:bc4a2ddf84dd0cc13d74e1970a1471c2574ed6aa"
+        ";anchor=swh:1:rev:4a9d637ba507a2b93365250428e6e3f021f194d0"
+        ";path=/"
+    )
+    deposit_rows = [
+        {
+            "deposit.id": 1037,
+            "deposit.external_id": "hal-02960679",
+            "deposit.swhid_context": swhid,
+            "deposit.status": "done",
+            "deposit_request.metadata": None,
+            "deposit_request.date": datetime.datetime(
+                2020, 10, 9, 13, 38, 8, 269611, tzinfo=datetime.timezone.utc,
+            ),
+            "deposit_client.provider_url": "https://hal.archives-ouvertes.fr/",
+            "deposit_collection.name": "hal",
+            "auth_user.username": "hal",
+        },
+        {
+            "deposit.id": 1037,
+            "deposit.external_id": "hal-02960679",
+            "deposit.swhid_context": swhid,
+            "deposit.status": "done",
+            "deposit_request.metadata": extrinsic_metadata,
+            "deposit_request.date": datetime.datetime(
+                2020, 10, 9, 13, 38, 7, 394544, tzinfo=datetime.timezone.utc,
+            ),
+            "deposit_client.provider_url": "https://hal.archives-ouvertes.fr/",
+            "deposit_collection.name": "hal",
+            "auth_user.username": "hal",
+        },
+    ]
+
+    origin_url = "https://hal.archives-ouvertes.fr/hal-02960679"
+
+    storage = Mock()
+
+    def origin_get(urls):
+        assert urls == [origin_url]
+        return [Origin(url=origin_url)]
+
+    storage.origin_get.side_effect = origin_get
+    deposit_cur = get_mock_deposit_cur(deposit_rows)
+    handle_row(copy.deepcopy(row), storage, deposit_cur, dry_run=False)
+
+    deposit_cur.execute.assert_called_once()
+    deposit_cur.__iter__.assert_called_once()
+
+    assert storage.method_calls == [
+        call.origin_get([origin_url]),
+        call.raw_extrinsic_metadata_add(
+            [
+                RawExtrinsicMetadata(
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
+                    discovery_date=datetime.datetime(
+                        2020, 10, 9, 13, 38, 7, 394544, tzinfo=datetime.timezone.utc
+                    ),
+                    authority=HAL_AUTHORITY,
+                    fetcher=FETCHER,
+                    format="sword-v2-atom-codemeta-v2-in-json",
+                    metadata=json.dumps(extrinsic_metadata).encode(),
+                    origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:4a9d637ba507a2b93365250428e6e3f021f194d0"
+                    ),
+                ),
+            ]
+        ),
+        call.raw_extrinsic_metadata_add(
+            [
+                RawExtrinsicMetadata(
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
+                    discovery_date=datetime.datetime(
+                        2020, 10, 9, 13, 38, 25, 888646, tzinfo=datetime.timezone.utc
+                    ),
+                    authority=SWH_AUTHORITY,
+                    fetcher=FETCHER,
+                    format="original-artifacts-json",
+                    metadata=json.dumps(original_artifacts).encode(),
+                    origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:4a9d637ba507a2b93365250428e6e3f021f194d0"
+                    ),
                 ),
             ]
         ),
@@ -585,6 +761,7 @@ def test_deposit_3_and_wrong_external_id_in_metadata():
 
     row = {
         "id": b"\t5`S\xc4\x9a\xd0\xf9\xe6.Q\xc2\x9d>a|y\x11@\xdf",
+        "directory": DIRECTORY_ID,
         "date": datetime.datetime(2019, 5, 14, 0, 0, tzinfo=datetime.timezone.utc),
         "committer_date": datetime.datetime(
             2019, 5, 14, 0, 0, tzinfo=datetime.timezone.utc
@@ -608,7 +785,7 @@ def test_deposit_3_and_wrong_external_id_in_metadata():
         {
             "deposit.id": 268,
             "deposit.external_id": "f80482de-90a8-4c32-bce4-6f6918d492ff",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": extrinsic_metadata,
             "deposit_request.date": datetime.datetime(
@@ -621,7 +798,7 @@ def test_deposit_3_and_wrong_external_id_in_metadata():
         {
             "deposit.id": 268,
             "deposit.external_id": "f80482de-90a8-4c32-bce4-6f6918d492ff",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": None,
             "deposit_request.date": datetime.datetime(
@@ -634,7 +811,7 @@ def test_deposit_3_and_wrong_external_id_in_metadata():
         {
             "deposit.id": 268,
             "deposit.external_id": "f80482de-90a8-4c32-bce4-6f6918d492ff",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": extrinsic_metadata,
             "deposit_request.date": datetime.datetime(
@@ -647,7 +824,7 @@ def test_deposit_3_and_wrong_external_id_in_metadata():
         {
             "deposit.id": 268,
             "deposit.external_id": "f80482de-90a8-4c32-bce4-6f6918d492ff",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": None,
             "deposit_request.date": datetime.datetime(
@@ -679,10 +856,8 @@ def test_deposit_3_and_wrong_external_id_in_metadata():
         call.raw_extrinsic_metadata_add(
             [
                 RawExtrinsicMetadata(
-                    type=MetadataTargetType.REVISION,
-                    id=parse_swhid(
-                        "swh:1:rev:09356053c49ad0f9e62e51c29d3e617c791140df"
-                    ),
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
                     discovery_date=datetime.datetime(
                         2019, 5, 14, 7, 49, 36, 775072, tzinfo=datetime.timezone.utc
                     ),
@@ -691,16 +866,17 @@ def test_deposit_3_and_wrong_external_id_in_metadata():
                     format="sword-v2-atom-codemeta-v2-in-json",
                     metadata=json.dumps(extrinsic_metadata).encode(),
                     origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:09356053c49ad0f9e62e51c29d3e617c791140df"
+                    ),
                 ),
             ]
         ),
         call.raw_extrinsic_metadata_add(
             [
                 RawExtrinsicMetadata(
-                    type=MetadataTargetType.REVISION,
-                    id=parse_swhid(
-                        "swh:1:rev:09356053c49ad0f9e62e51c29d3e617c791140df"
-                    ),
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
                     discovery_date=datetime.datetime(
                         2019, 5, 14, 7, 28, 33, 210100, tzinfo=datetime.timezone.utc
                     ),
@@ -709,16 +885,17 @@ def test_deposit_3_and_wrong_external_id_in_metadata():
                     format="sword-v2-atom-codemeta-v2-in-json",
                     metadata=json.dumps(extrinsic_metadata).encode(),
                     origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:09356053c49ad0f9e62e51c29d3e617c791140df"
+                    ),
                 ),
             ]
         ),
         call.raw_extrinsic_metadata_add(
             [
                 RawExtrinsicMetadata(
-                    type=MetadataTargetType.REVISION,
-                    id=parse_swhid(
-                        "swh:1:rev:09356053c49ad0f9e62e51c29d3e617c791140df"
-                    ),
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
                     discovery_date=datetime.datetime(
                         2019, 5, 14, 7, 49, 36, 775072, tzinfo=datetime.timezone.utc
                     ),
@@ -727,6 +904,9 @@ def test_deposit_3_and_wrong_external_id_in_metadata():
                     format="original-artifacts-json",
                     metadata=json.dumps(dest_original_artifacts).encode(),
                     origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:09356053c49ad0f9e62e51c29d3e617c791140df"
+                    ),
                 ),
             ]
         ),
@@ -753,6 +933,7 @@ def test_deposit_3_and_no_swhid():
 
     row = {
         "id": b"\x91\xe5\xca\x8b'K\xf1\xa8cFd2\xd7Q\xf7A\xbc\x94\xba&",
+        "directory": DIRECTORY_ID,
         "date": datetime.datetime(2017, 1, 1, 0, 0, tzinfo=datetime.timezone.utc),
         "committer_date": datetime.datetime(
             2019, 11, 6, 14, 47, 30, tzinfo=datetime.timezone.utc
@@ -785,6 +966,7 @@ def test_deposit_3_and_unknown_deposit():
 
     row = {
         "id": b"\x8e\x9c\xee\x14\xa6\xad9\xbc\xa44pw\xb8\x7f\xb5\xbb\xd8\x95;\xb1",
+        "directory": DIRECTORY_ID,
         "date": datetime.datetime(
             2018, 7, 23, 12, 25, 45, 907132, tzinfo=datetime.timezone.utc
         ),
@@ -825,6 +1007,7 @@ def test_deposit_4_without_xmlns():
 
     row = {
         "id": b"\x03\x98\x7f\x05n\xafE\x96\xcd \xd7\xb2\xee\x01\xc9\xb8L\xed\xdf\xa8",
+        "directory": DIRECTORY_ID,
         "date": datetime.datetime(
             2018, 1, 17, 12, 49, 30, 902891, tzinfo=datetime.timezone.utc
         ),
@@ -847,7 +1030,7 @@ def test_deposit_4_without_xmlns():
         {
             "deposit.id": 79,
             "deposit.external_id": "hal-01243573",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": None,
             "deposit_request.date": datetime.datetime(
@@ -860,7 +1043,7 @@ def test_deposit_4_without_xmlns():
         {
             "deposit.id": 79,
             "deposit.external_id": "hal-01243573",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": extrinsic_metadata,
             "deposit_request.date": datetime.datetime(
@@ -892,10 +1075,8 @@ def test_deposit_4_without_xmlns():
         call.raw_extrinsic_metadata_add(
             [
                 RawExtrinsicMetadata(
-                    type=MetadataTargetType.REVISION,
-                    id=parse_swhid(
-                        "swh:1:rev:03987f056eaf4596cd20d7b2ee01c9b84ceddfa8"
-                    ),
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
                     discovery_date=datetime.datetime(
                         2018, 1, 17, 12, 49, 30, 645576, tzinfo=datetime.timezone.utc
                     ),
@@ -904,6 +1085,9 @@ def test_deposit_4_without_xmlns():
                     format="sword-v2-atom-codemeta-v2-in-json-with-expanded-namespaces",
                     metadata=json.dumps(extrinsic_metadata).encode(),
                     origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:03987f056eaf4596cd20d7b2ee01c9b84ceddfa8"
+                    ),
                 ),
             ]
         ),
@@ -931,6 +1115,7 @@ def test_deposit_4_wrong_origin():
 
     row = {
         "id": b"-{\xcec\x1f\xc7\x91\x08\x03\x11\xeb\x83\\GB\x8eXjn\xa4",
+        "directory": DIRECTORY_ID,
         "date": datetime.datetime(
             2018, 1, 10, 13, 14, 51, 77033, tzinfo=datetime.timezone.utc
         ),
@@ -953,7 +1138,7 @@ def test_deposit_4_wrong_origin():
         {
             "deposit.id": 75,
             "deposit.external_id": "hal-01588781",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": None,
             "deposit_request.date": datetime.datetime(
@@ -966,7 +1151,7 @@ def test_deposit_4_wrong_origin():
         {
             "deposit.id": 75,
             "deposit.external_id": "hal-01588781",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": extrinsic_metadata,
             "deposit_request.date": datetime.datetime(
@@ -998,10 +1183,8 @@ def test_deposit_4_wrong_origin():
         call.raw_extrinsic_metadata_add(
             [
                 RawExtrinsicMetadata(
-                    type=MetadataTargetType.REVISION,
-                    id=parse_swhid(
-                        "swh:1:rev:2d7bce631fc791080311eb835c47428e586a6ea4"
-                    ),
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
                     discovery_date=datetime.datetime(
                         2018, 1, 10, 13, 14, 50, 555143, tzinfo=datetime.timezone.utc
                     ),
@@ -1010,6 +1193,9 @@ def test_deposit_4_wrong_origin():
                     format="sword-v2-atom-codemeta-v2-in-json-with-expanded-namespaces",
                     metadata=json.dumps(extrinsic_metadata).encode(),
                     origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:2d7bce631fc791080311eb835c47428e586a6ea4"
+                    ),
                 ),
             ]
         ),
@@ -1060,6 +1246,7 @@ def test_deposit_missing_metadata_in_revision():
 
     row = {
         "id": b"\x03@v\xf3\xf4\x1e\xe1 N\xb9\xf6@\x82\xcb\xe6\xe9P\xd7\xbb\x8a",
+        "directory": DIRECTORY_ID,
         "date": datetime.datetime(
             2019, 2, 25, 15, 49, 16, 594536, tzinfo=datetime.timezone.utc
         ),
@@ -1082,7 +1269,7 @@ def test_deposit_missing_metadata_in_revision():
         {
             "deposit.id": 229,
             "deposit.external_id": "hal-01243573",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": None,
             "deposit_request.date": datetime.datetime(
@@ -1095,7 +1282,7 @@ def test_deposit_missing_metadata_in_revision():
         {
             "deposit.id": 229,
             "deposit.external_id": "hal-01243573",
-            "deposit.swh_id_context": swhid,
+            "deposit.swhid_context": swhid,
             "deposit.status": "success",
             "deposit_request.metadata": extrinsic_metadata,
             "deposit_request.date": datetime.datetime(
@@ -1129,10 +1316,8 @@ def test_deposit_missing_metadata_in_revision():
         call.raw_extrinsic_metadata_add(
             [
                 RawExtrinsicMetadata(
-                    type=MetadataTargetType.REVISION,
-                    id=parse_swhid(
-                        "swh:1:rev:034076f3f41ee1204eb9f64082cbe6e950d7bb8a"
-                    ),
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
                     discovery_date=datetime.datetime(
                         2019, 2, 25, 15, 49, 12, 302745, tzinfo=datetime.timezone.utc
                     ),
@@ -1141,16 +1326,17 @@ def test_deposit_missing_metadata_in_revision():
                     format="sword-v2-atom-codemeta-v2-in-json",
                     metadata=json.dumps(extrinsic_metadata).encode(),
                     origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:034076f3f41ee1204eb9f64082cbe6e950d7bb8a"
+                    ),
                 ),
             ]
         ),
         call.raw_extrinsic_metadata_add(
             [
                 RawExtrinsicMetadata(
-                    type=MetadataTargetType.REVISION,
-                    id=parse_swhid(
-                        "swh:1:rev:034076f3f41ee1204eb9f64082cbe6e950d7bb8a"
-                    ),
+                    type=MetadataTargetType.DIRECTORY,
+                    target=DIRECTORY_SWHID,
                     discovery_date=datetime.datetime(
                         2019, 2, 25, 15, 54, 30, 102072, tzinfo=datetime.timezone.utc
                     ),
@@ -1159,6 +1345,9 @@ def test_deposit_missing_metadata_in_revision():
                     format="original-artifacts-json",
                     metadata=json.dumps(dest_original_artifacts).encode(),
                     origin=origin_url,
+                    revision=parse_swhid(
+                        "swh:1:rev:034076f3f41ee1204eb9f64082cbe6e950d7bb8a"
+                    ),
                 ),
             ]
         ),
